<template>
	<div class="home-container">
		<div style="height: 100%">
		<el-form :model="form" label-width="150px" :rules="applyRules" ref="ruleFormRef">
			<div class="homeCard">
			<el-row>
				<el-col :span="12">
					<el-form-item label="作业人" prop="operatorUids">
						<el-select v-model="form.operatorUids" multiple>
							<el-option
									v-for="item in workerList"
									:key="item.uid"
									:label="item.username"
									:value="item.uid"
							/>
						</el-select>
					</el-form-item>
				</el-col>
				<el-col :span="12">
					<el-form-item label="作业时间" prop="workTimeLine">
						<el-date-picker
								v-model="form.workTimeLine"
								format="YYYY-MM-DD HH:mm"
								value-format="YYYY-MM-DD HH:mm:00"
								type="datetimerange"
								range-separator="至"
								start-placeholder="开始时间"
								end-placeholder="结束时间"
						/>
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="12">
					<el-form-item label="作业内容" prop="workContent">
						<el-input
								v-model="form.workContent"
								autosize
								type="textarea"
								placeholder="请输入作业内容"
						/>
					</el-form-item>
				</el-col>
				<el-col :span="12">
					<el-form-item label="作业地址" prop="workLocation">
						<el-input
								v-model="form.workLocation"
								autosize
								type="textarea"
								placeholder="请输入作业地址"
						/>
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="12">
					<el-form-item label="危害辨识" prop="hazardIdentification">
						<el-input
								v-model="form.hazardIdentification"
								placeholder="请输入危害辨识"
						/>
					</el-form-item>
				</el-col>
        <el-col :span="12">
          <el-form-item label="关联视频设备" prop="cameraIds">
            <el-select v-model="form.cameraIds" multiple>
              <el-option
                  v-for="item in deviceList"
                  :key="item.id"
                  :label="item.name"
                  :value="item.id"
              />
            </el-select>
          </el-form-item>
        </el-col>
			</el-row>
				<el-divider border-style="dashed" />
			<el-row>
				<el-col :span="12">
					<el-form-item label="受限空间所属单位" prop="workDetail.csDepId">
<!--						<el-select v-model="form.workDetail.csDepId">-->
<!--							<el-option-->
<!--									v-for="item in csDepList"-->
<!--									:key="item.value"-->
<!--									:label="item.label"-->
<!--									:value="item.value"-->
<!--							/>-->
<!--						</el-select>-->
						<el-cascader v-model="form.workDetail.csDepId" :options="departList" :props="casProps" :show-all-levels="false" @change="handleChange" />
					</el-form-item>
				</el-col>
				<el-col :span="12">
					<el-form-item label="受限空间名称" prop="workDetail.csName">
						<el-input
								v-model="form.workDetail.csName"
								autosize
								type="textarea"
								placeholder="请输入"
						/>
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="12">
					<el-form-item label="空间内原有介质" prop="workDetail.csOriginalName">
						<el-input
								v-model="form.workDetail.csOriginalName"
								autosize
								type="textarea"
								placeholder="请输入"
						/>
					</el-form-item>
				</el-col>
				<el-col :span="12">
					<el-form-item label="关联作业" prop="workDetail.otherSpecialWork">
						<el-select v-model="form.workDetail.otherSpecialWork" multiple>
							<el-option v-for="item in otherWorkList" :key="item.value" :label="item.label" :value="item.label" />
						</el-select>
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="12">
					<el-form-item label="选择关联物资">
						<el-button type="primary" @click="openMaList">选择物资标准</el-button>
					</el-form-item>
				</el-col>
			</el-row>
			</div>
		</el-form>
      <material-dialog ref="material" @conFirmMaterials="conFirmMaterials"></material-dialog>
		<div class="applyBtn">
			<el-button type="primary" size="large" plain @click="submitForm(ruleFormRef)">发起申请</el-button>
		</div>
	</div>
	</div>
</template>

<script lang="ts">
import {toRefs, reactive, defineComponent, ref, defineAsyncComponent} from 'vue';
	import { storeToRefs } from 'pinia';
	import { initBackEndControlRoutes } from '/@/router/backEnd';
	import {useUserInfo} from "/@/stores/userInfo";
	import { Session } from '/@/utils/storage';
	import { Search } from '@element-plus/icons-vue'
	import { ElMessage, ElMessageBox } from 'element-plus'
	import type { FormInstance, FormRules } from 'element-plus'
	import { workApplyApi } from '/@/api/specialWorkSystem/workApply';

	interface stateType {
		form: Object,
		csDepList: Array<any>,
		otherWorkList: Array<any>,
		casProps: {},
		equipmentDialog: boolean
	}
	export default defineComponent({
		name: 'spaceForm',
		components: {
      materialDialog: defineAsyncComponent(() => import('/@/views/specialWorkSystem/workTicket/zysq/components/materialDialog.vue')),
    },
		props:['workerList','departList','deviceList'],
		setup(props: any, context: any) {
			const userInfo = useUserInfo()
			const { userInfos } = storeToRefs(userInfo);
			const state  = reactive<stateType>({
				equipmentDialog: false,
				form: {
					operatorUids: [],
					workType: 2,
					workLevel: 0,
					workContent: '',
					workLocation: '',
          maBaseId: null,
					hazardIdentification: '',
          cameraIds: [],
					workDetail:{
						csDepId: null,
						csName: '',
						csOriginalName: '',
						otherSpecialWork: []
					},
          receiveUids: [],
					workTimeLine: [],
					expStartTime: '',
					expEndTime: ''
				},
				csDepList: [
					{
						label: "单位一",
						value: 1
					},
					{
						label: "单位二",
						value: 2
					},
					{
						label: "单位三",
						value: 3
					},
					{
						label: "单位四",
						value: 4
					},
					{
						label: "单位五",
						value: 5
					},
					{
						label: "单位六",
						value: 6
					}
				],
				casProps: {
					emitPath: false,
					value: 'depId',
					label: 'depName',
					multiple: false,
					expandTrigger: 'hover',
					checkStrictly: true
				},
				otherWorkList: [
					{
						label: '动火作业',
						value: 1
					},
					{
						label: '受限空间作业',
						value: 2
					},
					{
						label: '吊装作业',
						value: 3
					},
					{
						label: '动土作业',
						value: 4
					},
					{
						label: '断路作业',
						value: 5
					},
					{
						label: '高处作业',
						value: 6
					},
					{
						label: '临时用电作业',
						value: 7
					},
					{
						label: '盲板抽堵作业',
						value: 8
					}
				]
			});
      const material = ref()
			const ruleFormRef = ref<FormInstance>()
			const applyRules = reactive<FormRules>({
				operatorUids: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
				workType: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
				workContent: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
				workLocation: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
				hazardIdentification: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
        cameraIds: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
				workTimeLine: [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
				"workDetail.csDepId": [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
				"workDetail.csName": [{ required: true, message: '该内容不能为空', trigger: 'blur' }],
				"workDetail.csOriginalName": [{ required: true, message: '该内容不能为空', trigger: 'blur' }]
			});

			// const toZero = (value: string | number,index: number,name: string,x:number) =>{
			// 	if(!value){
			// 		state.materialList[index][name][x].value = 0
			// 	}
			// }

      const openMaList = ()=>{
        if(state.form.operatorUids == []){
          ElMessage({
            type: 'warning',
            message: '请先选择作业人再获取相应物资配置'
          });
        }else{
          if(material.value.receiveUids.length==0){
            material.value.receiveUids = state.form.operatorUids
          }
          material.value.getMaList(state.form.workType,state.form.workLevel)
          material.value.workerList = props.workerList
        }
      }
      const conFirmMaterials = (receiveUids: Array<number>,chosenId: number) =>{
        state.form.maBaseId = null
        state.form.receiveUids = []
        state.form.receiveUids = receiveUids
        state.form.maBaseId = chosenId
      }

			const submitForm = async (formEl: FormInstance | undefined) => {
				if (!formEl) return
				await formEl.validate(async (valid, fields) => {
					if (valid) {
						state.form.expStartTime = JSON.parse(JSON.stringify(state.form.workTimeLine))[0]
						state.form.expEndTime = JSON.parse(JSON.stringify(state.form.workTimeLine))[1]
						let { workTimeLine, ...data } = JSON.parse(JSON.stringify(state.form))
						data.workDetail.otherSpecialWork = data.workDetail.otherSpecialWork.join(',')
						console.log(data,'data')
						const res = await workApplyApi().postSpaceApply(data)
						if (res.data.code === '200') {
								ElMessage({
									type: 'success',
									message: '提交成功！'
								});
								formEl.resetFields()
						} else {
							ElMessage({
								type: 'warning',
								message: res.data.msg
							});
						}
            material.value.maBaseId = null
            material.value.receiveUids = []
					} else {
						console.log('error submit!', fields)
					}
				})
			}


			// 折线图
			const renderMenu = async (value: string) => {
				Session.set('projectId',value)
				userInfos.value.projectId = value
				await initBackEndControlRoutes();
			};
			return {
				renderMenu,
				Search,
				ruleFormRef,
				applyRules,
        material,
        openMaList,
        conFirmMaterials,
				submitForm,
				...toRefs(state),
			};
		},
	});
</script>

<style scoped lang="scss">
	.home-container {
		height: 100%;
		overflow: hidden;
		position: relative;
		.homeCard{
			width: 100%;
			padding: 20px;
			box-sizing: border-box;
			background: #fff;
			border-radius: 4px;
			margin-bottom: 20px;
		}
		.applyBtn{
			width: 100%;
			background: #fff;
			padding-top: 15px;
			z-index: 5;
			box-shadow: 0 -3px 8px rgba(150,150,150,.1);
			display: flex;
			align-items: center;
			justify-content: center;
		}
		.el-row{
			margin-bottom: 20px;
		}
		.el-row:last-child {
			margin-bottom: 0;
		}
		.el-input{
			width: 100% !important;
		}
		.el-date-editor::v-deep{
			width: 100%;
		}
		.el-select{
			width: 100%;
		}
		:deep(.el-cascader){
			width: 100% !important;
		}
	}
</style>
